geowatch.tasks.tracking.polygon\_extraction module
==================================================

.. automodule:: geowatch.tasks.tracking.polygon_extraction
   :members:
   :undoc-members:
   :show-inheritance:
